NLSL: bincom Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
bincom Module Reference

## Variables
integer, parameter | nb =2*(mxlval+8)+2
integer, parameter | nbncf =nb*(nb+1)+1
integer, dimension(nb), save | bncfx
double precision, dimension(nbncf), save | bncf

## Variable Documentation

double precision, dimension(nbncf), save bincom::bncf

Definition at line 21 of file bincom.f90.

integer, dimension(nb), save bincom::bncfx

Definition at line 20 of file bincom.f90.

integer, parameter bincom::nb =2*(mxlval+8)+2

Definition at line 17 of file bincom.f90.

integer, parameter bincom::nbncf =nb*(nb+1)+1

Definition at line 18 of file bincom.f90.